use crate::utils::cmd::Cmd;

use super::{PackageError, PackageList, SpecificPackageManager};

#[derive(Debug)]
pub struct ArchlinuxPackageManager;

impl SpecificPackageManager for ArchlinuxPackageManager {
    fn name(&self) -> &'static str {
        "pacman"
    }
    
    fn update(&self) -> Result<(), PackageError> {
        let res = Cmd::new("pacman").arg("-Sy").run()?;

        if ! res.success {
            return Err(PackageError::CmdFail(res));
        }

        Ok(())
    }

    fn install(&self, list: PackageList) -> Result<(), PackageError> {
        let res = Cmd::new("pacman").arg("-S").args(list.list()).run()?;

        if ! res.success {
            return Err(PackageError::CmdFail(res));
        }

        Ok(())
    }

    fn remove(&self, _list: PackageList) -> Result<(), PackageError> {
        let res = Cmd::new("pacman").arg("-R").args(list.list()).run()?;

        if ! res.success {
            return Err(PackageError::CmdFail(res));
        }

        Ok(())
    }
}
